@extends ('layouts.patient')

@section('inner-content')
    <link href='/fullcalendar-5.3.2/lib/main.css' rel='stylesheet' />
    <script src='/fullcalendar-5.3.2/lib/main.js'></script>
    <div class="d-flex align-items-center pb-2">
        <h4 class="font-weight-bold m-0 font-size-16">
            {{ $appointment && $appointment->uid ? 'Edit Appointment' : 'Create Appointment' }}
        </h4>
    </div>
    <hr class="mt-2 mb-3">
    <div class="d-flex align-items-start appt-form">
        <form action="/api/appointment/{{ $appointment && $appointment->uid ? 'update' : 'create' }}" method="post" class="appt-form-col pr-2">
            @if($appointment && $appointment->uid)
                <input name="uid" type="hidden" value="{{ $appointment->uid }}">
            @else
                <input name="clientUid" type="hidden" value="{{ $patient->uid }}">
            @endif
            <div class="mb-3">
                <label class="text-secondary mb-1">Patient</label>
                <div class="font-weight-bold">{{ $patient->displayName() }}</div>
            </div>
            <div class="mb-3">
                <label class="text-secondary mb-1">Pro *</label>
                <select name="proUid" class="form-control form-control-sm">
                    <option value="">-- select --</option>
                    @foreach($pros as $iPro)
                        <option value="{{$iPro->uid}}" {{ $iPro->uid === $pro->uid ? 'selected' : '' }}>{{$iPro->displayName()}}</option>
                    @endforeach
                </select>
            </div>
            <div class="mb-3">
                <label class="text-secondary mb-1">Timezone *</label>
                <select name="timeZone" class="form-control form-control-sm" required>
                    <option value=""> --select-- </option>
                    <option {{ ($appointment && $appointment->timezone === 'EASTERN') || (!$appointment || !$appointment->uid) ? 'selected' : '' }}
                            value="EASTERN">Eastern</option>
                    <option {{ $appointment && $appointment->timezone === 'CENTRAL' ? 'selected' : '' }}
                            value="CENTRAL">Central</option>
                    <option {{ $appointment && $appointment->timezone === 'MOUNTAIN' ? 'selected' : '' }}
                            value="MOUNTAIN">Mountain</option>
                    <option {{ $appointment && $appointment->timezone === 'PACIFIC' ? 'selected' : '' }}
                            value="PACIFIC">Pacific</option>
                    <option {{ $appointment && $appointment->timezone === 'ALASKA' ? 'selected' : '' }}
                            value="ALASKA">Alaska</option>
                    <option {{ $appointment && $appointment->timezone === 'HAWAII' ? 'selected' : '' }}
                            value="HAWAII">Hawaii</option>
                    <option {{ $appointment && $appointment->timezone === 'PUERTO_RICO' ? 'selected' : '' }}
                            value="PUERTO_RICO">Puerto Rico</option>
                </select>
            </div>
            <div class="mb-3">
                <label class="text-secondary mb-1">Date *</label>
                <input name="date" class="form-control form-control-sm" type="date"
                       value="{{ $appointment && $appointment->raw_date ? $appointment->raw_date : date('Y-m-d') }}"
                       required>
            </div>
            <div class="mb-3">
                <label class="text-secondary mb-1">Start Time *</label>
                <input name="startTime" class="form-control form-control-sm" type="time"
                       value="{{ $appointment && $appointment->raw_start_time ? $appointment->raw_start_time : '' }}"
                       required>
            </div>
            <div class="mb-3">
                <label class="text-secondary mb-1">End Time</label>
                <input name="endTime" class="form-control form-control-sm" type="time"
                       value="{{ $appointment && $appointment->raw_end_time ? $appointment->raw_end_time : '' }}">
            </div>
            <div class="mb-3">
                <label class="text-secondary mb-1">Title</label>
                <input name="title" class="form-control form-control-sm" type="text"
                       value="{{ $appointment && $appointment->title ? $appointment->title : '' }}"
                       placeholder="(optional)">
            </div>
            <div class="mb-3">
                <label class="text-secondary mb-1">Description</label>
                <textarea name="description" class="form-control form-control-sm"
                          type="text"
                          placeholder="(optional)"
                >{{ $appointment && $appointment->description ? $appointment->description : '' }}</textarea>
            </div>
            <div class="mb-3">
                <button class="btn btn-sm btn-primary d-block w-100 font-weight-bold apply-appt-button" disabled>
                    @if($appointment && $appointment->uid)
                        Update Appointment
                    @else
                        Book Appointment
                    @endif
                </button>
            </div>
        </form>
        <div class="appt-calendar-col pl-2 border-left border-light">
            <div class="stag-fc-container">

            </div>
        </div>
    </div>
    <script>
        (function() {
            let calendarObject = null;
            function init() {
                calendarObject = new FullCalendar.Calendar($('.stag-fc-container')[0], {
                    headerToolbar: {
                        left: 'prev,next today',
                        center: 'title',
                        right: 'dayGridMonth,timeGridWeek,timeGridDay'
                    },
                    initialDate: '{{ date('Y-m-d') }}',
                    editable: false,
                    navLinks: true,
                    dayMaxEvents: false,
                    events: function(info, successCallback, failureCallback) {
                        let proUid = $('.appt-form [name="proUid"]').val();
                        if(!proUid) {
                            successCallback([]); // no events if no pro selected
                            return;
                        }
                        let timeZone = $('.appt-form [name="timeZone"]').val();
                        if(!timeZone) {
                            successCallback([]); // no events if no tz selected
                            return;
                        }
                        $.get('/api/appointment/getAllAppointmentsForPro' +
                            '?proUid=' + proUid +
                            '&start=' + info.startStr.substr(0, 10) +
                            '&end=' + info.endStr.substr(0, 10) +
                            '&timeZone=' + timeZone, function(_data) {
                        // $.get('/api/appointment/getAllAppointmentsForPro?start=1990-01-01&end=2025-01-01&timeZone=CENTRAL', function(_data) {
                            if(_data && _data.success) {
                                successCallback(_data.data);
                            }
                            else {
                                failureCallback('Unable to fetch appointments!');
                            }
                        }, 'json');
                    },
                    loading: function(bool) {

                    },
                    dateClick: function(info) {
                        $('.appt-form td.stag-selected').removeClass('stag-selected');
                        $(info.dayEl).addClass('stag-selected');
                        $('.appt-form [name="date"]').val(info.dateStr.substr(0, 10));
                        $('.apply-appt-button').prop('disabled', false);
                    },
                    eventClassNames: function(arg) {
                        @if($appointment && $appointment->uid)
                            if(arg.event.extendedProps.appointmentUid === '{{ $appointment->uid }}') {
                                return ['stag-current-appt'];
                            }
                        @endif
                    }
                });
                calendarObject.render();

                $(document).on('change', '.appt-form [name="proUid"], .appt-form [name="timeZone"]', function() {
                    calendarObject.refetchEvents();
                });

                $(document).on('change', '.appt-form [name="date"]', function() {
                    $('.appt-form td.stag-selected').removeClass('stag-selected');
                    if(!$(this).val()) return;
                    calendarObject.gotoDate($(this).val());
                    $('.fc-day[data-date="' + $(this).val() + '"]').addClass('stag-selected');
                });

                $('.appt-form [name="date"]').trigger('change');

                $('form.appt-form-col').on('submit', function() {
                    let form = $(this);
                    if(!form[0].checkValidity()) {
                        form[0].reportValidity();
                        return false;
                    }
                    $('.appt-form [name="startTime"]').val($('.appt-form [name="startTime"]').val().substr(0, 5));
                    $('.appt-form [name="endTime"]').val($('.appt-form [name="endTime"]').val().substr(0, 5));
                    $.post(form.attr('action'), form.serialize(), function(_data) {
                        if(_data && _data.success) {
                            @if($appointment && $appointment->uid)
                                toastr.success('Appointment updated successfully');
                                $('.apply-appt-button').prop('disabled', true);
                            @else
                                toastr.success('Appointment booked successfully');
                            @endif
                            calendarObject.refetchEvents();
                        }
                        else {
                            if(_data && _data.message) {
                                toastr.error(_data.message);
                            }
                            else {
                                @if($appointment && $appointment->uid)
                                    toastr.error('Unable to update appointment!');
                                @else
                                    toastr.error('Unable to book appointment!');
                                @endif

                            }
                        }
                    }, 'json');
                    return false;
                });

                $(document).on('change input paste', '.appt-form-col *', function() {
                    updateCalendarTitle();
                    $('.apply-appt-button').prop('disabled', false);
                });

                function updateCalendarTitle() {
                    $('.stag-calendar-header-extra').remove();
                    if(!$('.appt-form [name="proUid"]').val() || !$('.appt-form [name="timeZone"]').val()) {
                        $('.fc-toolbar-title').parent().addClass('mb-3').removeClass('text-center');
                        return;
                    }
                    else {
                        $('.fc-toolbar-title').parent().removeClass('mb-3').addClass('text-center');
                    }
                    let html = '<div class="stag-calendar-header-extra d-inline-flex">' +
                        '<span class="text-secondary">Pro:</span>&nbsp;' +
                        '<span class="font-weight-bold mr-4">' + $('.appt-form [name="proUid"] option:selected').text() + '</span>' +
                        '<span class="text-secondary">Times in</span>&nbsp;' +
                        '<span class="font-weight-bold">' + $('.appt-form [name="timeZone"] option:selected').text() + '</span>' +
                        '</div>';
                    $(html).insertAfter('.fc-toolbar-title');
                }

                updateCalendarTitle();
            }
            addMCInitializer('patient-manage-appointment', init);
        })();
    </script>
@endsection
